@@ -22,6 +22,8 @@
 #ifndef TERMINAL_SCREEN_H
 #define TERMINAL_SCREEN_H
 
+#include <gtk/gtkbin.h>
+
 #include "terminal-profile.h"
 
 G_BEGIN_DECLS
@@ -42,19 +44,20 @@ typedef struct _TerminalScreenPrivate TerminalScreenPrivate;
 
 struct _TerminalScreen
 {
-  GObject parent_instance;
+  GtkBin parent_instance;
 
   TerminalScreenPrivate *priv;
 };
 
 struct _TerminalScreenClass
 {
-  GObjectClass parent_class;
+  GtkBinClass parent_class;
 
-  void (* profile_set)       (TerminalScreen *screen);
-  void (* title_changed)     (TerminalScreen *screen);
-  void (* selection_changed) (TerminalScreen *screen);
-  void (* encoding_changed)  (TerminalScreen *screen);
+  void (* profile_set)        (TerminalScreen *screen);
+  void (* title_changed)      (TerminalScreen *screen);
+  void (* icon_title_changed) (TerminalScreen *screen);
+  void (* selection_changed)  (TerminalScreen *screen);
+  void (* encoding_changed)   (TerminalScreen *screen);
 };
 
 GType terminal_screen_get_type (void) G_GNUC_CONST;
@@ -83,7 +86,9 @@ int terminal_screen_get_id (TerminalScreen *screen);
 
 void terminal_screen_launch_child (TerminalScreen *screen);
 
-const char* terminal_screen_get_title (TerminalScreen *screen);
+const char* terminal_screen_get_title          (TerminalScreen *screen);
+const char* terminal_screen_get_icon_title     (TerminalScreen *screen);
+gboolean    terminal_screen_get_icon_title_set (TerminalScreen *screen);
 
 void terminal_screen_close (TerminalScreen *screen);
 
@@ -92,18 +97,25 @@ gboolean terminal_screen_get_text_selected (TerminalScreen *screen);
 void terminal_screen_edit_title (TerminalScreen *screen,
                                  GtkWindow      *transient_parent);
 
-void        terminal_screen_set_dynamic_title (TerminalScreen *screen,
-                                               const char     *title);
-const char *terminal_screen_get_dynamic_title (TerminalScreen *screen);
+void        terminal_screen_set_dynamic_title      (TerminalScreen *screen,
+                                                    const char     *title);
+void        terminal_screen_set_dynamic_icon_title (TerminalScreen *screen,
+                                                    const char     *title);
+const char *terminal_screen_get_dynamic_title      (TerminalScreen *screen);
+const char *terminal_screen_get_dynamic_icon_title (TerminalScreen *screen);
 
 void        terminal_screen_set_working_dir   (TerminalScreen *screen,
                                                const char     *dirname);
+void        terminal_screen_set_environ       (TerminalScreen *screen,
+                                               char          **env);
 const char *terminal_screen_get_working_dir   (TerminalScreen *screen);
 
 void        terminal_screen_set_font_scale    (TerminalScreen *screen,
                                                double          factor);
 double      terminal_screen_get_font_scale    (TerminalScreen *screen);
 
+void terminal_screen_update_scrollbar (TerminalScreen *screen);
+
 /* Allow scales a bit smaller and a bit larger than the usual pango ranges */
 #define TERMINAL_SCALE_XXX_SMALL   (PANGO_SCALE_XX_SMALL/1.2)
 #define TERMINAL_SCALE_XXXX_SMALL  (TERMINAL_SCALE_XXX_SMALL/1.2)
