@@ -42,8 +42,10 @@ void terminal_app_new_profile (TerminalApp     *app,
 void terminal_app_new_terminal (TerminalApp     *app,
                                 TerminalProfile *profile,
                                 TerminalWindow  *window,
+                                TerminalScreen  *screen,
                                 gboolean         force_menubar_state,
                                 gboolean         forced_menubar_state,
+                                gboolean         start_fullscreen,
                                 char           **override_command,
                                 const char      *geometry,
                                 const char      *title,
@@ -52,7 +54,8 @@ void terminal_app_new_terminal (TerminalApp     *app,
                                 double           zoom,
                                 const char      *startup_id,
                                 const char      *display_name,
-                                int              screen_number);
+                                int              screen_number,
+				char           **env);
 
 void terminal_app_manage_profiles (TerminalApp     *app,
                                    GtkWindow       *transient_parent);
@@ -68,6 +71,8 @@ void terminal_util_show_error_dialog (GtkWindow *transient_parent,
                                       GtkWidget **weap_ptr, 
                                       const char *message_format, ...) G_GNUC_PRINTF(3, 4);
 
+void terminal_util_show_help (const char *topic, GtkWindow  *transient_parent);
+
 void terminal_util_set_labelled_by          (GtkWidget  *widget,
                                              GtkLabel   *label);
 void terminal_util_set_atk_name_description (GtkWidget  *widget,
